@@ -10,6 +10,7 @@ from django.conf import settings
 from django.core.cache import cache
 from django.core.management.base import CommandError, BaseCommand
 
+from sveedocuments.settings_local import DOCUMENTS_CACHE_KEYS_TO_CLEAN
 from sveedocuments.models import Page, Insert
 
 class Command(BaseCommand):
@@ -30,7 +31,7 @@ class Command(BaseCommand):
 
     def do_clearcache(self):
         """
-        Clear all possible caches from the parser for documents
+        Clear all possible caches from documents
         """
         inserts = Insert.objects.all().order_by('id')
         for instance_item in inserts:
@@ -39,6 +40,9 @@ class Command(BaseCommand):
         pages = Page.objects.all().order_by('id')
         for page_item in pages:
             keys = page_item.clear_cache()
+        
+        if DOCUMENTS_CACHE_KEYS_TO_CLEAN:
+            cache.delete_many(DOCUMENTS_CACHE_KEYS_TO_CLEAN)
             
         if self.verbosity:
             print "* All documents cache cleared"
